use cgmath::{Angle, Deg, Point2, Vector2};

pub struct PhysicsBody {
	pub pos: Point2<f32>,
	pub vel: Vector2<f32>,
	pub mass: f32,
	pub angle: Deg<f32>,
}

impl PhysicsBody {
	pub fn new(pos: Point2<f32>) -> Self {
		return PhysicsBody {
			pos,
			vel: (0.0, 0.0).into(),
			mass: 0.3,
			angle: Deg(0.0),
		};
	}

	/// Calculate the position of this body after t seconds.
	pub fn tick(&mut self, t: f32) {
		self.pos += self.vel * t;
	}

	/// Apply an instantaneous force to this object
	pub fn force(&mut self, v: Vector2<f32>) {
		self.vel += v / self.mass;
	}

	/// Apply a force in the direction this object is pointing.
	pub fn thrust(&mut self, f: f32) {
		let l = Vector2 {
			x: -self.angle.sin(),
			y: self.angle.cos(),
		} * f;
		self.force(l);
	}

	// Rotate this object
	pub fn rot(&mut self, a: Deg<f32>) {
		self.angle -= a;

		// Wrap angles
		if self.angle.0.abs() > 180.0 {
			self.angle -= Deg(self.angle.0.signum() * 360.0);
		}
	}
}
